==> haskell-ghc-syntax-highlighter-0.0.9.0-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.9.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.9.0-I1mD3ni7LxX9yFqU1eQo3l
key:                  ghc-syntax-highlighter-0.0.9.0-I1mD3ni7LxX9yFqU1eQo3l
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  20e119bdf180f1b26836f49f89cefcb7
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.9.0-I1mD3ni7LxX9yFqU1eQo3l
depends:
    base-4.17.2.1 ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-syntax-highlighter-0.0.9.0-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.9.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.9.0-8ldjeexDvh92TzPnQtNzp4
key:                  ghc-syntax-highlighter-0.0.9.0-8ldjeexDvh92TzPnQtNzp4
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  494f54688e76e5dc5f050fb775093432
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.9.0-8ldjeexDvh92TzPnQtNzp4
depends:
    base-4.17.2.1 ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
